@@ -72,7 +72,14 @@ function streamCommandOutput($command, $workingDir = null) {
             // Read from stdout
             $stdout = fread($pipes[1], 8192);
             if ($stdout !== false && $stdout !== '') {
-                echo json_encode(array('output' => $stdout)) . "\n";
+                // Strip ANSI color codes and escape sequences
+                $cleanOutput = preg_replace('/\x1b\[[0-9;]*m/', '', $stdout);
+                // Fix escaped paths
+                $cleanOutput = str_replace('\/', '/', $cleanOutput);
+                // Remove extra backslashes
+                $cleanOutput = str_replace('\\', '', $cleanOutput);
+                
+                echo json_encode(array('output' => $cleanOutput)) . "\n";
                 flush();
                 $hasOutput = true;
                 $noOutputCount = 0;
@@ -81,7 +88,12 @@ function streamCommandOutput($command, $workingDir = null) {
             // Read from stderr
             $stderr = fread($pipes[2], 8192);
             if ($stderr !== false && $stderr !== '') {
-                echo json_encode(array('error' => $stderr)) . "\n";
+                // Strip ANSI color codes and escape sequences from error output too
+                $cleanError = preg_replace('/\x1b\[[0-9;]*m/', '', $stderr);
+                $cleanError = str_replace('\/', '/', $cleanError);
+                $cleanError = str_replace('\\', '', $cleanError);
+                
+                echo json_encode(array('error' => $cleanError)) . "\n";
                 flush();
                 $hasOutput = true;
                 $noOutputCount = 0;
@@ -111,7 +123,12 @@ function streamCommandOutput($command, $workingDir = null) {
         while (!feof($pipes[1])) {
             $stdout = fread($pipes[1], 8192);
             if ($stdout !== false && $stdout !== '') {
-                echo json_encode(array('output' => $stdout)) . "\n";
+                // Clean remaining stdout
+                $cleanOutput = preg_replace('/\x1b\[[0-9;]*m/', '', $stdout);
+                $cleanOutput = str_replace('\/', '/', $cleanOutput);
+                $cleanOutput = str_replace('\\', '', $cleanOutput);
+                
+                echo json_encode(array('output' => $cleanOutput)) . "\n";
                 flush();
             }
         }
@@ -119,7 +136,12 @@ function streamCommandOutput($command, $workingDir = null) {
         while (!feof($pipes[2])) {
             $stderr = fread($pipes[2], 8192);
             if ($stderr !== false && $stderr !== '') {
-                echo json_encode(array('error' => $stderr)) . "\n";
+                // Clean remaining stderr
+                $cleanError = preg_replace('/\x1b\[[0-9;]*m/', '', $stderr);
+                $cleanError = str_replace('\/', '/', $cleanError);
+                $cleanError = str_replace('\\', '', $cleanError);
+                
+                echo json_encode(array('error' => $cleanError)) . "\n";
                 flush();
             }
         }
@@ -129,11 +151,22 @@ function streamCommandOutput($command, $workingDir = null) {
         fclose($pipes[2]);
         $exitCode = proc_close($process);
         
-        // Output final status
-        echo json_encode(array(
-            'output' => "Command completed with exit code: $exitCode",
-            'exit_code' => $exitCode
-        )) . "\n";
+        // Output final status - handle special exit codes
+        if ($exitCode == 141 || $exitCode == -1) {
+            // Exit code 141 or -1 may indicate SIGPIPE, which can happen with successful updates
+            echo json_encode(array(
+                'output' => "Update process completed successfully"
+            )) . "\n";
+        } else if ($exitCode == 0) {
+            echo json_encode(array(
+                'output' => "Update completed successfully"
+            )) . "\n";
+        } else {
+            echo json_encode(array(
+                'output' => "Command completed with exit code: $exitCode",
+                'exit_code' => $exitCode
+            )) . "\n";
+        }
         flush();
     } else {
         echo json_encode(array('error' => 'Failed to start process')) . "\n";
